@@ -29,7 +29,7 @@ class ParamSurf : public AbstractSurface
 {
 public:
     CONSTRUCTORS(ParamSurf)
-    TYPE_NAME(QT_TR_NOOP("Parametric Surface"))
+    TYPE_NAME(QT_TRANSLATE_NOOP("Function type", "Parametric Surface"))
     EXPRESSION_TYPE(Analitza::ExpressionType(Analitza::ExpressionType::Lambda).addParameter(
                 Analitza::ExpressionType(Analitza::ExpressionType::Value)).addParameter(
                 Analitza::ExpressionType(Analitza::ExpressionType::Value)).addParameter(
