@@ -32,7 +32,7 @@ public:
     explicit SphericalSurface(const Analitza::Expression& e);
     SphericalSurface(const Analitza::Expression& e, Analitza::Variables* v);
     
-    TYPE_NAME(QT_TR_NOOP("Spherical Surface Radial=F(t:Azimuth, p: Polar)"))
+    TYPE_NAME(QT_TRANSLATE_NOOP("Function type", "Spherical Surface Radial=F(t:Azimuth, p: Polar)"))
     EXPRESSION_TYPE(Analitza::ExpressionType(Analitza::ExpressionType::Lambda).addParameter(
                         Analitza::ExpressionType(Analitza::ExpressionType::Value)).addParameter(
                         Analitza::ExpressionType(Analitza::ExpressionType::Value)).addParameter(
